@@ -10,18 +10,17 @@ class RobotFactory(object):
     def __init__(self, label):
         self.token = config(label, 'token')
         self.url = config(label, 'url')
-        self.number = config(label, "")
+        self.number = config(label, "number")
         self.headers = {'Content-Type': 'application/json'}
 
-    def send_message(self, content: str, phone: list):
+    def send_message(self, content: str):
         try:
             message = {
-                "msgtype": "text",
-                "text": {
-                    "mentioned_list": [],
-                    "content": content,
-                    "mentioned_mobile_list": phone
-                }
+                "content": content,
+                "notifyParams": [{
+                    "type": "jobNos",
+                    "values": self.number.split(",")
+                }]
             }
             _code = 0
             res = requests.post(self.url + self.key, headers=self.headers, data=json.dumps(message), timeout=10)
